==> cipux_3.2.0.orig.tar.gz: cipux/cibot/src/sh/setup_ldap_objects.sh <==
#!/bin/bash
# +=======================================================================+
# || cipux_setup_ldap_objects                                            ||
# ||                                                                     ||
# || The script uses CipUX and the cipux_task_* scripts to create the    || 
# || CipUX default LDAP structure concerning the default roles.          ||
# ||                                                                     ||
# ||                                                                     ||
# || (c) 2005 by Christian Kuelker                                       ||
# ||                                                                     ||
# ||  License: GPLv2 (GPL version 2 or later)                            ||
# ||                                                                     ||
# +=======================================================================+

DELETE='jradmins students teachers machines admins'
ROLE='none student teacher tutor assistent guest examinee'
OTHER='course examination'
ADMIN=cipadmin
PASSWORD=`grep Ldap_Password /etc/cipux/cipux.conf|sed -e 's/Ldap_Password=//g'|sed -e 's/ //g'`

# TODO: some shell guru may write an interactive password question

if [ "$PASSWORD" == "" ]; then
  echo "USAGE: cipux_setup_ldap_objects DEFAULT_PASSWORD"
  exit 1
else

  if [ -d /var/log/cipux ]; then
    echo " log dir exists ..."
  else
    echo " creating log dir /var/log/cipux ..." 
    mkdir -p /var/log/cipux
  fi  

  # arder important: first "none"

  for i in $DELETE; do
    echo "delete wlus objects $i (if it is there, just to be save)"
    cipux_task_delete_user $i >/dev/null
  done


  for i in $ROLE; do
    echo "delete role $i (if it is there, just to be save)"
    cipux_task_delete_user $i >/dev/null
    echo "create role $i ..."
    # cipux_task_create_user UID firstname lastname role password
    cipux_task_create_user $i CipUX Role none $PASSWORD
    sleep 1
    cipux_set_value -u $i -e cipuxRole -v role
    cipux_set_value -c $i -e cipuxRole -v skel
    cipux_set_value -c $i -e groupType -v shared
  done

  for i in $ADMIN; do
    echo "delete admin $i (if it is there, just to be save)"
    cipux_task_delete_user $i >/dev/null
    echo "create admin $i ..."
    # cipux_task_create_user UID firstname lastname role password
    cipux_task_create_user $i Adminstrator CipUX none $PASSWORD
    sleep 1
    cipux_set_value -c $i -e cipuxRole -v admin
  done

  for i in $OTHER; do
    echo "delete other role $i (if it is there, just to be save)"
    cipux_task_delete_user $i >/dev/null
    echo "create other role $i ..."
    cipux_task_create_user $i CipUX CourseRole none $PASSWORD
    sleep 1
    cipux_set_value -u $i -e cipuxRole -v meta
    cipux_set_value -c $i -e cipuxRole -v skel
    cipux_set_value -c $i -e groupType -v shared
  done
fi

==> cipux_3.2.6.orig.tar.gz: cipux/cibot/src/sh/setup_ldap_objects.sh <==
#!/bin/bash
# +=======================================================================+
# || cipux_setup_ldap_objects                                            ||
# ||                                                                     ||
# || The script uses CipUX and the cipux_task_* scripts to create the    ||
# || CipUX default LDAP structure concerning the default roles.          ||
# ||                                                                     ||
# ||                                                                     ||
# || (c) 2005 by Christian Kuelker                                       ||
# ||                                                                     ||
# ||  License: GPLv2 (GPL version 2 or later)                            ||
# ||                                                                     ||
# +=======================================================================+

DELETE='jradmins students teachers machines admins'
ROLE='none student teacher tutor assistent guest examinee skel'
OTHER='course examination'
GROUP='nogroup'
SKEL='noskel'
ADMIN=cipadmin
PASSWORD=`grep Ldap_Password /etc/cipux/cipux.conf|sed -e 's/Ldap_Password=//g'|sed -e 's/ //g'`

# TODO: some shell guru may write an interactive password question

if [ "$PASSWORD" == "" ]; then
  echo "USAGE: cipux_setup_ldap_objects DEFAULT_PASSWORD"
  exit 1
else

  if [ -d /var/log/cipux ]; then
    echo " log dir exists ..."
  else
    echo " creating log dir /var/log/cipux ..."
    mkdir -p /var/log/cipux
  fi

  # arder important: first "none"

  for i in $DELETE; do
    echo "delete wlus objects $i (if it is there, just to be save)"
    cipux_task_delete_user $i >/dev/null
  done


  for i in $ROLE; do
    echo "delete role $i (if it is there, just to be save)"
    cipux_task_delete_role $i >/dev/null
    echo "create role $i ..."
    # !!! we have to take user because refine_homedir will fail (this roles DO NOT exist)
    # cipux_task_create_object UID firstname lastname urole grole gtype password
    cipux_task_create_object   $i  CipUX     role     role  none  shared $PASSWORD
    sleep 1;
    cipux_set_value -c $i -e cipuxRole -v skel
  done

  for i in $ADMIN; do
    echo "delete admin $i (if it is there, just to be save)"
    cipux_task_delete_user $i >/dev/null
    echo "create admin $i ..."
    # cipux_task_create_user UID firstname lastname role password
    cipux_task_create_user $i Adminstrator CipUX none $PASSWORD
    sleep 1
    cipux_set_value -c $i -e cipuxRole -v admin
  done

  for i in $SKEL; do
    echo "delete skel $i (if it is there, just to be save)"
    cipux_task_delete_skel $i >/dev/null
    echo "create skel $i ..."
    # cipux_task_create_user UID firstname lastname role password
    cipux_task_create_skel $i $PASSWORD > /dev/null/ 2>&1
  done


  for i in $OTHER; do
    echo "delete other role $i (if it is there, just to be save)"
    cipux_task_delete_user $i >/dev/null
    echo "create other role $i ..."
    cipux_task_create_user $i CipUX CourseRole none $PASSWORD
    sleep 1
    cipux_set_value -u $i -e cipuxRole -v meta
    cipux_set_value -c $i -e cipuxRole -v skel
    cipux_set_value -c $i -e groupType -v shared
  done

  for i in $GROUP; do
    echo "delete group $i (if it is there, just to be save)"
    cipux_task_delete_course $i >/dev/null
    echo "create group $i ..."
    # cipux_task_create_user UID firstname lastname role password
    cipux_task_create_course $i $PASSWORD > /dev/null/ 2>&1
  done

fi
